# eric7.WebBrowser.WebAuth.Fido2PinDialog

Module implementing a dialog to enter the current and potentially new PIN.

### Global Attributes

None

### Classes

Fido2PinDialog | Class implementing a dialog to enter the current and potentially new PIN.
Fido2PinDialogMode | Class defining the various PIN dialog mode.

### Functions

None

## Fido2PinDialog

Class implementing a dialog to enter the current and potentially new PIN.

### Derived from

QDialog, Ui_Fido2PinDialog

### Class Attributes

None

### Class Methods

None

### Methods

Fido2PinDialog | Constructor
__checkPins | Private slot to check the entered PIN(s).
__showPinErrors | Private method to show some error messages.
getPins | Public method to get the entered PINs.
on_newPinButton_toggled | Private slot to handle the toggling of the new PIN visibility.
on_pinButton_toggled | Private slot to handle the toggling of the PIN visibility.

### Static Methods

None

#### Fido2PinDialog (Constructor)

Fido2PinDialog(mode, title, message, minLength, retries, parent=None)

Constructor

mode (Fido2PinDialogMode)
  mode of the dialog
title (str)
  header title to be shown
message (str)
  more decriptive text to be shown
minLength (int)
  minimum PIN length
retries (int)
  number of attempts remaining before the security key get locked
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### Fido2PinDialog.__checkPins

__checkPins()

Private slot to check the entered PIN(s).

Appropriate error messages are shown in case of issues and the state of the OK button is set accordingly.

#### Fido2PinDialog.__showPinErrors

__showPinErrors(errorMessages)

Private method to show some error messages.

errorMessages (list of str)
  list of error messages

#### Fido2PinDialog.getPins

getPins()

Public method to get the entered PINs.

Return:
  tuple containing the current and new PIN

Return Type:
  tuple of (str, str)

#### Fido2PinDialog.on_newPinButton_toggled

on_newPinButton_toggled(checked)

Private slot to handle the toggling of the new PIN visibility.

checked (bool)
  state of the new PIN visibility button

#### Fido2PinDialog.on_pinButton_toggled

on_pinButton_toggled(checked)

Private slot to handle the toggling of the PIN visibility.

checked (bool)
  state of the PIN visibility button

Up

## Fido2PinDialogMode

Class defining the various PIN dialog mode.

### Derived from

enum.Enum

### Class Attributes

CHANGE
GET
SET

### Class Methods

None

### Methods

None

### Static Methods

None

Up